Struct aligned_buffer_pool::PooledValidator
source · pub struct PooledValidator { /* private fields */ }Trait Implementations
sourceimpl<E> ArchiveContext<E> for PooledValidatorwhere
ArchiveValidator: ArchiveContext<E>,
impl<E> ArchiveContext<E> for PooledValidatorwhere
ArchiveValidator: ArchiveContext<E>,
sourcefn check_subtree_ptr(
&mut self,
ptr: *const u8,
layout: &Layout
) -> Result<(), E>
fn check_subtree_ptr( &mut self, ptr: *const u8, layout: &Layout ) -> Result<(), E>
Checks that the given data address and layout is located completely
within the subtree range.
sourceunsafe fn push_prefix_subtree_range(
&mut self,
root: *const u8,
end: *const u8
) -> Result<Range<usize>, E>
unsafe fn push_prefix_subtree_range( &mut self, root: *const u8, end: *const u8 ) -> Result<Range<usize>, E>
Pushes a new subtree range onto the validator and starts validating it. Read more
sourceimpl Debug for PooledValidator
impl Debug for PooledValidator
sourceimpl Drop for PooledValidator
impl Drop for PooledValidator
Registers the given
ptr as a shared pointer with the given type. Read moreAuto Trait Implementations
impl Freeze for PooledValidator
impl RefUnwindSafe for PooledValidator
impl Send for PooledValidator
impl Sync for PooledValidator
impl Unpin for PooledValidator
impl UnwindSafe for PooledValidator